#
# rpm spec for Window Switch
#

%{!?_libexecdir: %define _libexecdir /usr/lib}
%{!?rpm_hints: %define rpm_hints 1}
%{!?nautilus_lib: %define nautilus_lib %{_libdir}/nautilus}
%if 0%{?build_no} == 0
%define build_no 1
%endif

%define VERSION 0.12.23


%define is_suse %(test -e /etc/SuSE-release && echo 1 || echo 0)
%define is_fedora %(test -e /etc/fedora-release && echo 1 || echo 0)
%define is_centos %(test -e /etc/redhat-release && grep -q CentOS /etc/redhat-release && echo 1 || echo 0)
%define fedora 0
%if %is_fedora
%define fedora %(cat /etc/fedora-release | awk '{print $3}')
%endif


# Basic groups of dependencies (platform specific overrides below)
%define xorg_utils xorg-x11-server-utils
%define python_base pygtk2, python-crypto, python-twisted, python-imaging, python-xlib
%define python_extras nautilus-python, dbus-python
%define proto_deps xpra, nx, rdesktop, openssh-clients, tigervnc, tigervnc-server

%if 0%{?el6}
#no nx
%define proto_deps xpra, rdesktop, openssh-clients, tigervnc, tigervnc-server
#no python-xlib
%define python_base pygtk2, python-crypto, python-twisted, python-imaging
%endif
%if 0%{?el7}
#no rdesktop, no nx
%define proto_deps xpra, openssh-clients, tigervnc, tigervnc-server
#no python-xlib, twisted-core only:
%define python_base pygtk2, python-crypto, python-twisted-core, python-imaging
%endif
%define mdns avahi
%define gstreamer gstreamer
%define pyasn1 python-pyasn1
%define xorg_extras dbus-x11, xloadimage, devilspie, ImageMagick
%define recommends_base gnome-menus, gnome-python2, xfreerdp
%if %{is_fedora}
#fedora no longer handles rpm "hints"
%define rpm_hints 0
#adds python-utmp and python-svg
%define python_extras nautilus-python, python-utmp, gnome-python2-rsvg
%define mdns avahi avahi-ui-tools
#avahi-ui-tools contains non-ui stuff we need (!)
%endif

#default value (specfile editor hack):
%define recommends %{recommends_base}, %{xorg_extras}

# SUSE: uses totally different package names... (sigh)
%if %is_suse
%define pyasn1 python-asn1
%define xorg_utils xorg-x11-server-extra
%define python_base python-gtk, python-crypto, python-twisted, python-imaging, python-xlib
%define python_extras python-nautilus, dbus-1-python, python-utmp
# no tigervnc, xfreerdp or NX in default repos.. and dbus-x11 is called dbus-1-x11
%define proto_deps xpra, rdesktop, openssh
%define mdns avahi, python-avahi
%define xorg_extras dbus-1-x11, xloadimage, devilspie
%define recommends_base gnome-menus, python-gnome
%define recommends %{recommends_base}, %{xorg_extras}
%endif
%if %is_centos
%define python_extras dbus-python
%define recommends %{recommends_base}
%define nautilus_lib /usr/lib/nautilus
%define mdns avahi avahi-tools
%endif
%if 0%{?rhel} >= 7
%define rpm_hints 0
%endif

#only pure python, no debug:
%global debug_package %{nil}
 

Summary: Front end for controlling remote desktop sessions.
Vendor: devloop.org.uk
Name: winswitch
Version: %{VERSION}
Release: %{build_no}
License: GPL3
Requires: %{python_base}, %{python_extras}, %{proto_deps}, %{xorg_utils}, %{pyasn1}, %{mdns}, %{gstreamer}, python
#Fedora stopped supporting "(hints)" in Fedora 15?
%if %{rpm_hints}
Requires(hint): %{recommends}
%endif
Group: Networking
Packager: Antoine Martin <antoine@nagafix.co.uk>
URL: http://winswitch.org/
Source: winswitch-%{VERSION}.tar.bz2
BuildRoot: %{_tmppath}/%{name}-%{VERSION}-root
Obsoletes: shifter
%if %is_fedora
BuildRequires: python, setuptool
%endif


%description
Start and control remote GUI sessions via xpra, NX, VNC, RDP or plain ssh X11 forwarding.
You can start, suspend, resume and send supported sessions to other clients.

%changelog
* Mon Nov 28 2016 Antoine Martin <antoine@nagafix.co.uk> 0.12.23-1
- Xpra compatibility fixes

* Wed Apr 20 2016 Antoine Martin <antoine@nagafix.co.uk> 0.12.22-1
- Xpra compatibility fixes
- ubundle Xpra from the MS Windows and Mac OS X packages
- fix SSH issues: update to latest Twisted and Plink (except for Windows XP)
- trim unnecessary package dependencies
- disable unused sound options
- fix access to global settings on Mac OS X
- fix mdns with newer avahi library versions

* Tue May 19 2015 Antoine Martin <antoine@nagafix.co.uk> 0.12.21-1
- improved compatibility with newer versions of xpra
- fix loading of desktop files with multiple entries
- remove bashism from script

* Tue Nov 05 2013 Antoine Martin <antoine@nagafix.co.uk> 0.12.20-1
- better compatibility with newer versions of xpra
- update application workaround database

* Sat Jun 29 2013 Antoine Martin <antoine@nagafix.co.uk> 0.12.19-1
- fix local display session detection with python-utmp
- fix local display detection when running server separately from applet
- fix error handling for VirtualBox session detection

* Wed Dec 12 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.18-1
- osx fixes for command line paths in disk image
- support shadowing via xpra (v0.8 or later)
- don't try to rotate logs error when not logging to file
- refactor and cleanup exec code
- refresh list of users connected when connection state changes
- relax preloaded session parameter matching

* Mon Oct 08 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.17-1
- fix for platforms without a known installer tool or packagekit
- fix for long keyboard layout names with nx
- fix for log rotation: don't log after rotating!
- fix for xpra v0.7.0 log format
- update debian packaging files
- rename main unix display session using the user's full name if available
- refactor most tests to use common code
- build warnings, missing description strings, fewer errors in logs, etc

* Tue Sep 11 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.16-7
- fix nx suspend

* Mon Sep 10 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.16-1
- fix log file rotation (prevented auto-start on KDE, and other problems)
- fix missing icon for system tray on some platforms/desktops
- fix pre-loading and pre-connection of Xpra sessions
- fix error notifications shown when stopping or disconnecting from a server
- fix NX keyboard mapping
- packaging fixes: dependencies updates, version and change detection
- select more suitable server for start session dialogs
- packaging fixes: dependencies updates, version and change detection
- offer to install mDNS support via packagekit on Linux
- source RPMs fixed

* Mon Aug 20 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.15-1
- fix Xpra "force stop" (now needs password)
- fix GStreamer video: try to use the default video plugin if preferences are not set
- fix mDNS warning on startup (dialog was making the UI unresponsive)
- fix default protocol options were ignored when not using dialogs to start sessions
- fix SELinux warning counter: honour it and only shown the warning 3 times
- support for Xpra 0.5 (new log file format, automatic xvfb settings)
- use packagekit for installing new protocols easily
- if sshd is not installed, assume that ssh mode will not work
- avoid warning that "xpra is too old" when it is not installed
- various cleanups

* Mon Jun 04 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.14-1
- xpra use x264 or vpx encoding by default for video applications
- drop compatiblity for xpra versions older than 0.1
- drop compatiblity for winswitch versions older than 0.12.8

* Tue Apr 24 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.13-1
- Support for latest xpra features (x264 and vpx encoding)
- Rotate log files by default
- fix error when trying to save preferences
- parse user's application launchers from ~/.local/share/applications if present
- fix icon loading for menu categories


* Wed Mar 21 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.12-1
- fix missing tray icon with Ubuntu 11.10 (properly this time)
- fix keyboard mapping issues with NX sessions
- fix NX sessions on Mac OS X
- fix for xpra sessions wrongly detected as X11 sessions
- Android improvements: ability to start sessions, update all dialogs as needed, handle sessions with shadows
- Android fixes: allow spaces in message text, etc
- new configuration file for each protocol backend, so individual protocols can easily be disabled
- GStreamer codecs were not detected when reloading settings from file
- Mac OS X library updates: gtk-osx, netifaces 0.8, Twisted 12, etc
- MS Windows library updates: pywin32 217, Twisted 12, netifaces 0.7, etc
- avoid error when stopping a local embedded connection
- better default sizes for windows so they don't overflow the screen (session info, start app)


* Tue Feb 14 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.11-1
- fix detection of local displays
- avoid logging errors on disconnection
- fix missing list of audio and video codecs (re-detect on start)

* Fri Feb 10 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.10-1
- fix laptop suspend bug: ensure we can always re-connect to a server
- fix VNC/NX full desktop sessions start dialog
- upgrade xpra sessions running older versions
- grab existing xpra sessions started externally
- don't bother running the idle check timer when the option is not enabled (or not available)
- in window mode allow enter "enter" and "space" keys to be used to activate buttons in dialogs
- MS Windows clients: disconnect xpra sessions cleanly and remove the system tray

* Sat Jan 21 2012 Antoine Martin <antoine@nagafix.co.uk> 0.12.9-1
- fix compatibility with pycrypto 2.5
- fix headless client (winswitch_client) was  not starting
- fix for non-automatic TCP port connection mode
- fix start application dialog could fail
- handle new Xpra options (some require 'advanced mode' to be enabled)
- handle SIGUSR1/SIGUSR2 for debugging purposes
- do not show screen size selection widget for seamless sessions
- ensure the local timezone is always present in the list of default options
- UI enhancements to prevent windows getting squashed or resized

* Fri Dec 30 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.8.1-1
- Fix race in system tray setup code which can prevent it from showing

* Fri Dec 30 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.8-1
- Window UI mode: option to use a window rather than a system tray icon anchor
- VirtualBox session support (limited but functional)
- fix for threading issue causing freezes
- fix re-connection: correctly drop dead connections (aka laptop suspend bug)
- support for setting the session's timezone and locale in start dialog
- faster startup and display the system tray earlier to show progress
- ensure none of the dialog windows squash their contents
- per-protocol defaults configuration file
- support for running multiple instances on the same X11 server
	("WINSWITCH_HOME" environment variable)
- fix svn revision detection during build
- winswitch: support xpra's "--no-keyboard-sync" option
- improve local X11 display detection
- detect screen size changes and propagate them
- support for setting the keymap to use with rdesktop/xfreerdp

* Tue Nov 29 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.7.1-1
- notification via pynotify: typo fix
- re-fix NX support: subsequent refactoring had undone the fix..

* Mon Nov 28 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.7-1
- fix NX support: avoid trying to connect to a display before it is ready!
- fixed "double linked list corrupted" by using avahi ahead of pybonjour
- open remote links locally, in a new session, or within the existing session
- open remote files in a new session or within the existing session (as before)
- detect Ubuntu versions and avoid its broken appindicator API
- only check SELinux status once when running an embedded server
- better script for detecting reserved ports on SELinux systems
- split code in smaller utility classes to minimize imports


* Tue Oct 18 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.6-1
- support for ssh agent
- display server fingerprint as a picture using Vash (if Java is installed)
- support for Xpra-Xdummy combination, patched X11 server packages are available
- support for latest xpra 0.0.7.28 and its new options (system tray icon, etc)
- turn off xpra compression over fast links
- reduce lag of GStreamer based display shadowing over fast links

* Thu Sep 01 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.5-1
- VP8 video compression option for GStreamer screencasting
- better support for loading and resizing icons (inc SVG) on headless servers
- fix for applet messages received via local unix domain socket
- ability to install missing protocols more easily
- workaround memory and file descriptor leaks in buggy versions of Python
- use Growl for notifications if available
- show a bookmarks menu for easy access to session shortcuts
- better shadow error detection
- slow down local display detection when under heavy utmp traffic (batch delay)
- support for installing protocols on demand (NX, VNC, etc)
- avoid unhelpful mDNS warning when there are no network connections
- more robust local display detection on *nix
- systems using appindicator API are no longer missing the tray icon on startup

* Wed Jul 20 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.4-1
- remote ssh client helper now exits when the connection drops (no zombies!)
- disable pynotify when no notification daemon is running and use gtk fallback
- session sound can now be re-connected even after a winswitch server re-start
- resize all icons on the fly to save bandwidth
- the default icon and menu size was too big on some platforms
- handle invalid passphrases and key files better: try again, not erroring out
- better layout for start dialogs
- try harder to find a matching icon for commands
- use more efficient base64 for encoding data command strings (if supported)
- initial support for multiple audio codecs (still defaults to vorbis)
- cleaner separation of UI widgets and protocol handling code

* Tue Jun 14 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.3-1
- mDNS readers are now removed correctly (was causing segfaults on exit)
- exit cleanly on all platforms, freeing all resources and waiting if needed
- VNC full desktop sessions can be started more than once (oops)
- fix segfaults in the X11 session detection code
- fix file descriptor leaks in X11 code and screen capture
- support many more KDE applications using the "--nofork" parameter
- avoid sending really big icon files! (above 128KB)

* Mon May 30 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.2-6
- Fix for xpra session never terminating when command exits
- Fix for applications requiring access to gnome-keyring daemon

* Fri May 27 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.2-1
- KDE fix preventing the tray icon from being clicked on
- GStreamer audio and video now correctly stop when the client close it
- Support for Xpra's new 'adaptive JPEG' mode using bandwidth controls
- many new options can now be selected in the session dialogs

* Wed May 18 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.1-3
- one liner fix for menu not showing on KDE
- more RPM specfile dependency fixes for openSUSE

* Tue May 17 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.1-2
- RPM specfile dependency fixes for CentOS and openSUSE

* Wed May 4 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.1-1
- Fix spurious VNC timeouts due to log file buffering
- Avoid error message when SSH sessions terminate
- SSH needs password OR keys

* Mon May 2 2011 Antoine Martin <antoine@nagafix.co.uk> 0.12.0-1
- Adds GStreamer video streaming option for shadowing sessions
- Reliable sound support
- Xpra keyboard mapping fixes
- Detect applications that can only be started once per session and show warning
- Session pre-loading fixes
- Pre-connect to local sessions for ultra-fast startup
- Detect firewalls blocking mDNS

* Sun Apr 3 2011 Antoine Martin <antoine@nagafix.co.uk> 0.11.4-2
- Use /usr/lib for distributions that do not have /usr/libexec

* Tue Mar 29 2011 Antoine Martin <antoine@nagafix.co.uk> 0.11.4-1
- File transfers to remote servers without using SFTP
- Ability to whitelist server commands
- Stale connections are properly dropped, allowing re-connect to work
- Warn when files cannot be opened remotely
- Thunar file manager integration
- Moved most non user-visible commands to "/usr/libexec"
- Added "--help" and manual page to most commands
- Prevent code from logging ssh key passphrase in debug mode!

* Tue Mar 1 2011 Antoine Martin <antoine@nagafix.co.uk> 0.11.3-1
- Ability to integrate transparently into the main start menu
- Server will auto-start again when connecting over SSH
- Minor bugfixes

* Mon Jan 24 2011 Antoine Martin <antoine@nagafix.co.uk> 0.11.2-1
- Minor bug fixes

* Fri Dec 10 2010 Antoine Martin <antoine@nagafix.co.uk> 0.11.1-1
- Small GUI bug fixes
- SELinux detection
- Ability to start a custom command from the menus

* Sun Oct 10 2010 Antoine Martin <antoine@nagafix.co.uk> 0.11.0-1
- Complete re-write of the SSH transport layer using twisted-conch

* Wed Aug 11 2010 Antoine Martin <antoine@nagafix.co.uk> 0.10.0-1
- Complete rewrite of the sound support using gstreamer rtp, much more efficient than pulseaudio

* Sat May 08 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.19-1
- Fix some SSH tunnelling issues
- xpra preloading
- UI cleanup

* Thu May 06 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.18-1
- Another one-liner fix...

* Thu May 06 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.17-1
- Proper re-release, with fixlets for remote SSH servers and updated release files

* Thu May 06 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.16-1
- Windows and UI fixes

* Sat May 01 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.15-1
- Emergency release to fix annoying small bug in 0.9.14

* Sat May 01 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.14-1
- First release to support Windows servers

* Sat Apr 24 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.13-1
- Minor bug fixes

* Mon Apr 19 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.12-1
- Emergency fix for utmp errors

* Sat Apr 17 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.11-1
- Screenshot support

* Fri Apr 16 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.10-1
- Minor fixes

* Thu Apr 08 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.9-1
- first public release

* Mon Jan 11 2010 Antoine Martin <antoine@nagafix.co.uk> 0.9.0-1
- first rpm spec file


%prep
%setup -q

%build
%{__python} setup.py build

%install
rm -rf $RPM_BUILD_ROOT
NAUTILUS_LIB_DIR=%{nautilus_lib} %{__python} setup.py install -O1 --prefix /usr --skip-build --root %{buildroot}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc  COPYING
%{_bindir}/winswitch_*
%{_bindir}/wcw
/usr/lib*/python*/*packages/winswitch*
%{_libexecdir}/winswitch
/etc/winswitch
/usr/share/winswitch
/usr/share/applications/winswitch.desktop
/usr/share/icons
/usr/share/mime
/usr/share/man
/usr/share/Thunar
/usr/share/Vash
%{nautilus_lib}/extensions-2.0/python/nautilus_winswitch.*

###
### eof
###
